# WatchDoc

Markdown and Jupyter Notebook file watcher. It generates automatically a docx, a pptx, and a pdf for each md or ipynb file.


References for markdown: [Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
